@@ -21,7 +21,7 @@
 
 int new_handler_called = 0;
 
-void new_handler()
+void my_new_handler()
 {
     ++new_handler_called;
     std::set_new_handler(0);
@@ -38,7 +38,7 @@ struct A
 int main()
 {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-    std::set_new_handler(new_handler);
+    std::set_new_handler(my_new_handler);
     try
     {
         void* vp = operator new (std::numeric_limits<std::size_t>::max());
